@@ -239,13 +239,20 @@ def _get_org_update_args(args):
 
     if args.name is not None:
         org_update_inputs["name"] = args.name
+    if args.saml_idp is not None:
+        org_update_inputs["samlIdP"] = args.saml_idp
 
-    if args.member_list_visibility is not None or args.project_transfer_ability is not None:
+    if any(policy not in (None, False) for policy in (args.member_list_visibility, args.project_transfer_ability, args.enable_job_reuse, args.disable_job_reuse)):
         org_update_inputs["policies"] = {}
     if args.member_list_visibility is not None:
         org_update_inputs["policies"]["memberListVisibility"] = args.member_list_visibility
     if args.project_transfer_ability is not None:
-        org_update_inputs["policies"]["restrictProjectTransfer"] = args.project_transfer_ability
+        org_update_inputs["policies"]["restrictProjectTransfer"] = args.project_transfer_ability        
+    if args.enable_job_reuse == True:
+        org_update_inputs["policies"]["jobReuse"] = True
+    elif args.disable_job_reuse == True:
+        org_update_inputs["policies"]["jobReuse"] = False
+    
 
     return org_update_inputs
 
